
.. image:: https://img.shields.io/pypi/v/hoshi.svg?logo=pypi
    :target: https://pypi.org/project/hoshi

.. image:: https://img.shields.io/pypi/pyversions/hoshi.svg?logo=pypi
    :target: https://pypi.org/project/hoshi

.. image:: https://img.shields.io/travis/chintal/hoshi.svg?logo=travis
    :target: https://travis-ci.org/chintal/hoshi

.. image:: https://img.shields.io/coveralls/github/chintal/hoshi.svg?logo=coveralls
    :target: https://coveralls.io/github/chintal/hoshi

.. image:: https://img.shields.io/codacy/grade/86c7707114cc4353bc1c57a6a4ff467f/main
    :target: https://app.codacy.com/gh/chintal/hoshi

.. image:: https://img.shields.io/requires/github/chintal/hoshi.svg
    :target: https://requires.io/github/chintal/hoshi/requirements

.. image:: https://img.shields.io/pypi/l/hoshi.svg
    :target: https://www.gnu.org/licenses/gpl-3.0.en.html


.. inclusion-marker-do-not-remove

.. raw:: latex

       \vspace*{\fill}


This package provides primitives and highly opinionated infrastructure to
setup and manage i18n and i10n efforts for python projects. It is a thin
wrapper around `babel <http://babel.pocoo.org/en/latest/>`_, which you can
and probably should use directly if you are comfortable with it.


.. raw:: latex

    \clearpage
    \tableofcontents
    \clearpage


Package Information
-------------------

The latest version of the documentation, including installation, usage, and
API/developer notes can be found at
`ReadTheDocs <https://hoshi.readthedocs.io/en/latest/index.html>`_.

The latest version of the sources can be found at
`GitHub <https://github.com/chintal/hoshi>`_. Please use
GitHub's features to report bugs, request features, or submit pull/merge requests.

The principle author for ``hoshi`` is Chintalagiri Shashank. The
author can be contacted if necessary via the information on the
`author's github profile <https://github.com/chintal>`_ . See the AUTHORS file
for a full list of collaborators and/or contributing authors, if any.

``hoshi`` is distributed under the terms of the
`MIT License <https://spdx.org/licenses/MIT.html>`_ .
A copy of the text of the license is included along with the sources.
